/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2020-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-03-02, JO:   Initial version of revision history              **
** V1.0.1: 2022-01-21, JO:   EP-934: Updated copyright and branding           **
** V1.0.2: 2023-08-21, BG:   EP-1195: Updated compiler version to ARMCC V6    **
**                           Updated type conversion                          **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** BDRV_CCU6_ADC1_Motor: Running a motor with speed and direction control     **
********************************************************************************
** Use the MON1 button and the potentiometer to control the motor:            **
** Press MON1 Button:    Turn motor on/off                                    **
** Potentiometer:        Adjust the speed of the motor                        **
** variable motor_dir:   controls direction (clockwise LED4 (P0.2) on,        **
**                       counterclockwise LED3 (P0.1) on)                     **
*******************************************************************************/

#include "tle_device.h"


enum motor_directions_t
{
  direction_clockwise, 
  direction_counterclockwise
};


int main(void)
{
  uint16_t adc_poti;
	bool motor_on = false;
	/* Set motor_dir to direction_clockwise */
  /* motor_dir can also be set to direction_counterclockwise here */
	enum motor_directions_t motor_dir = direction_clockwise;
	

  /*****************************************************************************
  ** Initialization of the hardware modules based on the configuration set    **
  ** in Config Wizard                                                         **
  *****************************************************************************/
  TLE_Init();

  /* Initiate T12 shadow transfer */
  CCU6_T12_Str_En();
  /* Start T12 */
  CCU6_StartTmr_T12();
	
	/* Set PWM signals to LS1, HS1, LS2 and HS2 */
  BDRV_Set_Bridge(Ch_LS_PWM, Ch_PWM, Ch_LS_PWM, Ch_PWM);  
  
  /* Set PWM signals to be modulated according to motor_dir*/
	if(motor_dir == direction_clockwise)                    
	{
    PORT_P02_Output_High_Set();
    PORT_P01_Output_Low_Set();
	}
	else
	{
		PORT_P01_Output_High_Set();
    PORT_P02_Output_Low_Set();
	}
    
  for (;;)
  {
    /* Service watchdog timer */
		(void)WDT1_Service();
		
		/* If MON1 button has been pressed */
    if (MONx_Get_Status(1u) == 0)
    {
      /* Wait until MON1 buttom is released */
			MONx_Debounce(1u,1); 
			
			if(motor_on == false)
			{
				/* Turn motor on, T12 PWM pattern modulates CCU6 output signal */
				CCU6_T12_Modulation_En(CCU6_MASK_COUT60 | CCU6_MASK_CC60 | CCU6_MASK_COUT61 | CCU6_MASK_CC61); 
				motor_on = true;
			}
			else
			{
				/* Turn motor off */
				CCU6_T12_Modulation_En(0); 
				motor_on = false;
			}                  
    }
		else
		{
			/* Do nothing */
		}
    
    if (ADC1_GetChResult(&adc_poti, ADC1_CH7) == true)
		{	
			/* Return value is in range 0...1023 --> *2 to allow higher motor speed */
			adc_poti = adc_poti * 2;
			
			/* Limit duty cycle to 80% */
      if (adc_poti > (CCU6_T12PERIOD * 0.8)) 
			{
        adc_poti = (uint16)(CCU6_T12PERIOD * 0.8);
			}
		}
		
    /* Set new duty cycle in shadow register for Ch0 and Ch1 */
		if(motor_dir == direction_clockwise)
		{
      CCU6_Ch0_Value_Set(adc_poti);
      CCU6_Ch1_Value_Set(0);			
		}
		else
		{
      CCU6_Ch0_Value_Set(0);
      CCU6_Ch1_Value_Set(adc_poti);			
		}

    /* Initiate T12 shadow transfer */
    CCU6_T12_Str_En();
   }
}
