/******************************************************************************
*                _  _               ___             _                         *
*               (_)| |__   _ __    / _ \ _ __ ___  | |__    /\  /\            *
*               | || '_ \ | '__|  / /_\/| '_ ` _ \ | '_ \  / /_/ /            *
*               | || | | || |    / /_\\ | | | | | || |_) |/ __  /             *
*               |_||_| |_||_|    \____/ |_| |_| |_||_.__/ \/ /_/              *
*                                                                             *
*    ihr GmbH                                                                 *
*    Airport Boulevard B210                                                   *
*    77836 Rheinmnster - Germany                                             *
*    http://www.ihr.de                                                        *
*    Phone +49(0) 7229-18475-0                                                *
*    Fax   +49(0) 7229-18475-11                                               *
*                                                                             *
*******************************************************************************
*                                                                             *
* (c) Alle Rechte bleiben bei IHR GmbH, auch fuer den Fall von Schutzrechts-  *
* anmeldungen. Jede Verfuegungsbefugnis, wie Kopier- und Weitergaberecht      *
* bleibt bei IHR GmbH.                                                        *
*                                                                             *
* (c) All rights reserved by IHR GmbH including the right to file             *
* industrial property rights. IHR GmbH retains the sole power of              *
* disposition such as reproduction or distribution.                           *
*                                                                             *
********************     Workfile:      lin_hal.c        **********************
*                                                                             *
*  PROJECT-DESCRIPTION:  Infineon Hardware Abstraction Layer                  *
*  FILE-DESCRIPTION:     All Hardware Access Routines for LIN Driver          *
*                                                                             *
*******************************************************************************
*                                                                             *
*       Revision:        $Rev:: 780         $                                 *
*       Responsible:     B.Reiss                                              *
*       Co-Responsible:  P.Koch                                               *
*       Last Modtime:    $Date:: 2018-06-19#$                                 *
*                                                                             *
******************************************************************************/

/**
@file lin_hal.c
@brief Microcontroller specific implementation of the LIN Driver communication
*/

/* ===========================================================================
 *  Header files
 * ==========================================================================*/

#include "genLinConfig.h"
#include "lin_main.h"
#include "lin_slave_task.h"
#include "lin_driver_api.h"
#include "lin_type.h"
#include "lin_hal.h"
#if ((defined LIN_PROTOCOL_VERSION_2_0) || ((defined LIN_PROTOCOL_VERSION_2_1) && (!defined LIN_PROTOCOL_VERSION_2_2)))
#include "lin_config.h"
#endif /* end #if ((defined LIN_PROTOCOL_VERSION_2_0) || ((defined LIN_PROTOCOL_VERSION_2_1) && (!defined LIN_PROTOCOL_VERSION_2_2))) */

/* ===========================================================================
 *  Global Variables
 * ==========================================================================*/

LIN_hal_stat_reg_t lin_hal_status_g;
static l_u8 lin_hal_rx_data_guc;
static LIN_SLAVE_STATE_t lin_slave_state_g;
t_lin_temp_frame_buffer lin_temp_buffer;
static l_u8 uc_frame_lin_version;
static l_u8 temp_data_size_uc;
static LIN_TX_DATA_t lin_tx_data_g;
static LIN_FLAGS_t lin_flag_g;
static l_u8 lin_frm_timeout_timer;
static t_lin_timeout_ctrl lin_timeout_ctrl;
static l_u16 l_chk_sum_ui;
l_u8 l_txchk_byte_nr;

#ifdef AUTOBAUD_ENABLED
static volatile l_u8 lin_ab_t2_state;
static l_u8 lin_ab_timeout_timer;
static volatile l_u16 lin_synch_time;
#endif /* end #ifdef AUTOBAUD_ENABLED */

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
static volatile t_lin_master_ctrl lin_masterctrl;
static l_u8 guc_frame_id;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

/* ===========================================================================
 *  Functions prototypes
 * ==========================================================================*/

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
static void l_hal_master_send_sync(void);
static void l_hal_master_send_pid(void);
#else
#define l_hal_master_send_sync()               do { } while (0)
#define l_hal_master_send_pid()                do { } while (0)
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

#ifdef AUTOBAUD_ENABLED
static void lin_hal_init_T2 (void);
#endif /* #ifdef AUTOBAUD_ENABLED */

static void l_hal_tx_state_machine(void);
static void lin_hal_tx_checksum(l_u8 checksum);
static void lin_hal_tx_byte(l_u8 lin_hal_bytetoTX);
#if (defined J2602_PROTOCOL)
static void lin_hal_set_resp_error (l_u8 j2602_fault);
#else
static void lin_hal_set_resp_error (void);
#endif /* end #if defined J2602_PROTOCOL */
static void lin_hal_init_uart(void);
#ifdef AUTOBAUD_ENABLED
static void lin_hal_brreg_calc(void);
#endif /* ifdef AUTOBAUD_ENABLED */

/* ===========================================================================
 *  Functions
 * ==========================================================================*/

/* ---------------------------------------------------------------------------
 *  void lin_hal_init (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Initializes the HAL layer and UART / SCI
   @param  void
   @retval void
*/
void lin_hal_init (void)
{
   l_u8 loc_i;
   lin_hal_status_g.byte_received   = 0u;
   lin_hal_status_g.res0            = 0u;
   lin_hal_rx_data_guc              = 0u;
   uc_frame_lin_version             = 0u;
   temp_data_size_uc                = L_RESET;
   lin_tx_data_g.checksum           = 0u;
   lin_tx_data_g.data_puc           = 0u;
   lin_tx_data_g.index_uc           = 0u;
   lin_tx_data_g.length_c           = 0u;
   lin_tx_data_g.old_data_uc        = 0u;
   lin_flag_g.res0                  = 0u;
   lin_flag_g.tx_finished           = 0u;
   lin_flag_g.tx_next               = 0u;
   lin_frm_timeout_timer            = 0u;
   l_chk_sum_ui                     = 0u;
   l_txchk_byte_nr                  = 0u;
   lin_timeout_ctrl.byte = 0u;
   for(loc_i = 0u; loc_i < 11u; loc_i++)
   {
      lin_temp_buffer.byte[loc_i] = 0u;
   }
   lin_timeout_ctrl.flag.sys_init  = 1u;
   lin_hal_init_uart();
   lin_timeout_ctrl.flag.sys_init  = 0u;
#ifdef AUTOBAUD_ENABLED
   lin_ab_timeout_timer             = 0u;
   lin_ab_t2_state = 0u;
#endif /* end #ifdef AUTOBAUD_ENABLED */
   lin_slave_state_g = idle;
#if ((defined LIN_MASTER)||(defined J2602_MASTER))
   lin_masterctrl.byte = 0u;
   guc_frame_id = 0u;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */
   return;
}

#ifdef J2602_SLAVE
/* ---------------------------------------------------------------------------
 *  void j2602_hal_target_reset (l_u8 reset)
 * --------------------------------------------------------------------------*/

/**
   @brief  This function resets the controller after receiving a reset request.
   @pre    LIN driver initialized
   @param  reset  Sets reset flag every time, but reset all errors if zero, keeps all errors if non-zero
   @retval void
 */
void j2602_hal_target_reset (l_u8 reset) {
#ifndef GM_SPEC_ADAPTION
   /* Deleting all errors and set the status to RESET */
   if (reset)
   {
      g_j2602_status.flags.errorstate |= J2602_RESET_STATUS;
   }
   else
   {
      g_j2602_status.flags.errorstate = J2602_RESET_STATUS;
   }
#endif /* #ifdef GM_SPEC_ADAPTION */
   /* Setting of the response data is made when the response header was received
    * The response header will be sent only if the targeted reset was called, so
    * there is no need to make a difference between broadcast and target reset
    * here.
    */
   return;
}
#endif /* end #ifdef J2602_SLAVE */

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
/* ---------------------------------------------------------------------------
 *  void lin_hal_tx_header (l_u8 l_pid)
 * --------------------------------------------------------------------------*/
/**
   @brief  Starts sending the header on the bus
   @pre    LIN driver initialized
   @param  l_pid           PID of the frame
   @retval void
*/
void lin_hal_tx_header (l_u8 l_pid)
{
   /* Send dummy data to UART to send Break */
   LIN_UART_BCON_RUN =     0u;
   LIN_UART_BCON_FDSEL =   BREAK_BRG_FD_SEL;
   LIN_UART_BCON_BG =      BREAK_BRG_VAL;
   LIN_UART_BCON_RUN = 1u;
   LIN_UART_9BITTRANS = 0u;
   lin_hal_tx_char(BREAK_FIELD_k);
   lin_masterctrl.flag.break_transm = 1u;
   guc_frame_id = l_pid;
}
#endif /* end #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

/* ---------------------------------------------------------------------------
 *  static void lin_hal_tx_byte(l_u8 lin_hal_bytetoTX)
 * --------------------------------------------------------------------------*/
/**
   @brief  Transmits one byte on bus
   @pre    LIN driver initialized
   @param  lin_hal_bytetoTX           pointer to frame buffer
   @retval void
*/
static void lin_hal_tx_byte(l_u8 lin_hal_bytetoTX)
{
   /* Store value for receive check later */
   lin_tx_data_g.old_data_uc = lin_hal_bytetoTX;

   /* send data to uart, for transmit */
   lin_hal_tx_char(lin_hal_bytetoTX);

   /* make configuration for tx next data  */
   lin_tx_data_g.length_c--;
   /* check if next field is CRC */
   if(0u == lin_tx_data_g.length_c)
   {
      lin_flag_g.tx_next = CHECKSUM_NEXT;
   }
   else
   {
      lin_flag_g.tx_next = L_SET;
   }
}

/* ---------------------------------------------------------------------------
 *  void lin_hal_tx_response (l_u8 l_type, const l_u8 l_data[], l_u8 l_len)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function prepares the driver for transmitting a response frame.
   @pre    LIN driver initialized
   @param  l_u8 l_type   LIN type (1.3, 2.0, or 2.1)
   @param  l_u8 l_data[] Databuffer for frame data
   @param  l_u8 l_len    Length information of frame
   @retval void
*/
void lin_hal_tx_response (l_u8 l_type, const l_u8 l_data[], l_u8 l_len)
{
   l_u16 ui_I;
   l_u8 uc_temp_sum;

   lin_tx_data_g.index_uc = 0u;
   lin_slave_state_g = tx_data;
   lin_tx_data_g.length_c = l_len;
   g_lin_frame_data_size = l_len;
   if(l_type == LIN_2_X)
   {
      /* For LIN 2.x use PID & Data for CRC */
      l_chk_sum_ui = lin_temp_buffer.frame.PID;
   }
   else
   {
      l_chk_sum_ui = 0u;
   }
   g_lin_irqState = l_sys_irq_disable();
   /* Copy data from main buffer to the tx buffer */
   for(ui_I = 0u; ui_I < l_len; ui_I++)
   {
      lin_temp_buffer.frame.DataBuffer[ui_I] = l_data[ui_I];
   }
   l_sys_irq_restore(g_lin_irqState);

   l_txchk_byte_nr = lin_tx_data_g.length_c - 1u;
   l_chk_sum_ui += lin_temp_buffer.frame.DataBuffer[l_txchk_byte_nr];
   /* if sum is bigger than 16 bit */
   uc_temp_sum = (l_u8)(l_chk_sum_ui >> 8);
   l_chk_sum_ui = l_chk_sum_ui + uc_temp_sum;
   l_chk_sum_ui &= 0xFFu;
   /* frame with only 1 databyte */
   if (l_txchk_byte_nr == 0u)
   {
      lin_tx_data_g.checksum = (~(l_u8)l_chk_sum_ui);
   }

   /* start transmit of data fields */
   lin_hal_tx_byte(lin_temp_buffer.frame.DataBuffer[0]);
   lin_temp_buffer.frame.BufferIndex = 1u; /* Index of next data to transmit */
   lin_timeout_ctrl.flag.transm_ongoing = 1u;
   return;
}

/* ---------------------------------------------------------------------------
 *  static void l_hal_tx_state_machine (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function controls the transmission of frame data and checksum
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
static void l_hal_tx_state_machine (void)
{
   /* tx CRC of frame */
   if (lin_flag_g.tx_next == CHECKSUM_NEXT)
   {
      lin_hal_tx_checksum(lin_tx_data_g.checksum);
   }
   /* tx next byte of frame */
   if (lin_flag_g.tx_next == L_SET)
   {
      /* Set state machine to transmit data */
      lin_slave_state_g = tx_data;
      lin_hal_tx_byte(lin_temp_buffer.frame.DataBuffer[lin_temp_buffer.frame.BufferIndex]);
      lin_temp_buffer.frame.BufferIndex ++; /* Index of next data to transmit */
   }
}

/* ---------------------------------------------------------------------------
 *  void lin_hal_tx_wake_up(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function transmits a wake-up pulse on the bus
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
void lin_hal_tx_wake_up(void)
{
   l_u8 loc_data;

   /* Send dummy data to UART to send Break */
   loc_data = 0xe0u;
   lin_hal_tx_char(loc_data);
}

/* ---------------------------------------------------------------------------
 *  void l_hal_txchecksum_calculation(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function calculates the checksum of a publish frame step-wise
           for each byte that is actually transmitted.
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
void l_hal_txchecksum_calculation(void)
{
   l_u8 uc_temp_sum;

   l_txchk_byte_nr--;
   /*  l_chk_sum_ui += l_txchk_data_p[l_txchk_byte_nr]; */
   l_chk_sum_ui += lin_temp_buffer.frame.DataBuffer[l_txchk_byte_nr];
   /* if sum is bigger than 16 bit */
   uc_temp_sum = (l_u8)(l_chk_sum_ui >> 8);
   l_chk_sum_ui = l_chk_sum_ui + uc_temp_sum;
   l_chk_sum_ui &= 0xFFu;
   if (l_txchk_byte_nr == 0u)
   {
      lin_tx_data_g.checksum = ~(l_u8)l_chk_sum_ui;
      l_chk_sum_ui = 0u;
   }
}

/* ---------------------------------------------------------------------------
 *  static void lin_hal_tx_checksum(l_u8 checksum)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function transmits the checksum on the bus.
   @pre    LIN driver initialized
   @param  l_u8 checksum  The checksum of the frame.
   @retval void
*/
static void lin_hal_tx_checksum(l_u8 checksum)
{
   /* set next state in state machine */
   lin_slave_state_g = tx_checksum;

   /* send data to uart, for transmit */
   lin_hal_tx_char(checksum);

   /* store data for receive check later */
   lin_tx_data_g.old_data_uc = checksum;
   /* reset tx state finish transmit of frame */
   lin_flag_g.tx_next = L_RESET;
}

/* ---------------------------------------------------------------------------
 *  void lin_hal_rx_response (l_u8 l_type, l_u8 l_len)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function prepares the driver for receiving a subscribe frame.
   @pre    LIN driver initialized
   @param  l_u8 l_type  The LIN protocol version of the frame.
   @param  l_u8 l_len   The length information of the frame.
   @retval void
*/
void lin_hal_rx_response (l_u8 l_type, l_u8 l_len)
{
   g_lin_frame_data_size = l_len;
   temp_data_size_uc = g_lin_frame_data_size;
   uc_frame_lin_version = l_type;
   lin_slave_state_g = rx_data;
   lin_timeout_ctrl.flag.frame = 1u;
   lin_frm_timeout_timer = 0u;
   return;
}

/* ---------------------------------------------------------------------------
 *  void l_hal_rx_state_machine (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function steps through the states for receiving frame headers
           and frame data.
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
void l_hal_rx_state_machine (void)
{
   l_u8 uc_temp_sum = 0u;
   /* next computations depend on receive task state (state machine) */
   switch(lin_slave_state_g)
   {
      /* only valid next data is break/sync */
      case idle:
         break;

      /* if break received next data is sync field */
      case break_received:
#ifndef AUTOBAUD_ENABLED
         /* check if sync field else invalid_field error */
         if (lin_hal_rx_data_guc == SYNC_FIELD_k)
         {
            lin_slave_state_g = sync_received;
         }
         else
         {
            lin_hal_init_uart();
            lin_slave_state_g = idle;
         }
#endif /* end #ifndef AUTOBAUD_ENABLED */
         break;

      /* if sync field received next data is PID field */
      case sync_received:
         /* after sync field a pid field was received */
         /* reset lin_state_after receive of pid (Protocoll layer will set for further rx/tx action) */
         lin_slave_state_g = idle;
         /* check if pid is valid and if its tx or rx frame */
         lin_slave_task_rx_pid(lin_hal_rx_data_guc);
         break;

      /* if it is rx frame, then data field comes next */
      case rx_data:
         /* store received data and check for type of next field */
         lin_temp_buffer.frame.DataBuffer[(g_lin_frame_data_size - temp_data_size_uc)] = lin_hal_rx_data_guc;
         lin_timeout_ctrl.flag.frame = 1u;
         lin_timeout_ctrl.flag.transm_ongoing = 1u;
         lin_timeout_ctrl.flag.recept_started = 1u;
         lin_frm_timeout_timer = 0u;

         /* calculate temporary checksum (step wise after each byte) */
         if(g_lin_frame_data_size == temp_data_size_uc)
         {
            if (uc_frame_lin_version == LIN_2_X)
            {
               /* For LIN 2.x use PID & Data for CRC */
               l_chk_sum_ui = lin_temp_buffer.frame.PID;
            }
            else
            {
               l_chk_sum_ui = 0u;
            }
         }
         l_chk_sum_ui+= lin_temp_buffer.frame.DataBuffer[(g_lin_frame_data_size - temp_data_size_uc)];
         /* if sum is bigger than 16 bit */
         uc_temp_sum = (l_u8)(l_chk_sum_ui>>8);
         l_chk_sum_ui = l_chk_sum_ui + uc_temp_sum;
         l_chk_sum_ui &= 0xFFu;

         /* get number of data still to receive */
         temp_data_size_uc--;

         /* if no more data to receive got to rx_checksum state */
         if (temp_data_size_uc == 0u)
         {
            lin_slave_state_g = rx_checksum;
         }
         break;

      /* if last data was received next is crc field */
      case rx_checksum:
         l_chk_sum_ui = ((l_u16)(~l_chk_sum_ui)) & 0x00FFu;
#ifdef SUPPORT_TWO_BAUDRATES
         /* reset to higher baudrate if not yet set to a fixed value
            to be able to detect the lower one */
         l_hal_reset_to_high_baudrate();
#endif /* #ifdef SUPPORT_TWO_BAUDRATES */
         /* check if checksum was faulty */
         if (lin_hal_rx_data_guc != (l_chk_sum_ui))
         {
#if ((defined LIN_MASTER) && (defined LIN_EVENT_TRIGGERED_FRAME_ENABLE))
            /* J2602 does not support event triggered frames, so only for LIN Master relevant. */
            lin_master_check_etf();
#endif /* end #if ((defined LIN_MASTER) && (defined LIN_EVENT_TRIGGERED_FRAME_ENABLE)) */
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
#if ((defined LIN_MASTER)||(defined J2602_MASTER))
            if (g_lin_active_pid == 0x7Du)
#else
            if(g_lin_active_pid == 0x3Cu)
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */
            {
#if ((defined LIN_PROTOCOL_VERSION_2_0) || ((defined LIN_PROTOCOL_VERSION_2_1) && (!defined LIN_PROTOCOL_VERSION_2_2)))
               lin_diag_rx_chksum_error();
#endif /* end #if ((defined LIN_PROTOCOL_VERSION_2_0) || ((defined LIN_PROTOCOL_VERSION_2_1) && (!defined LIN_PROTOCOL_VERSION_2_2))) */
            }
            lin_hal_set_resp_error();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#ifdef J2602_PROTOCOL
            lin_hal_set_resp_error(J2602_CHECKSUM_ERROR);
#endif /* end #ifdef J2602_PROTOCOL */
         }
         else
         {
            /* notify upper layer about received frame. */
            lin_slave_task_rx_data();
         }
         lin_timeout_ctrl.flag.frame = 0u;
         lin_timeout_ctrl.flag.transm_ongoing = 0u;
         lin_timeout_ctrl.flag.recept_started = 0u;
         lin_frm_timeout_timer = 0u;
         /* Set LIN slave state to idle to wait for next frame */
         lin_slave_state_g = idle;
         break;

      case tx_checksum:
         /* check if transmission has crashed */
         if(lin_hal_rx_data_guc != lin_tx_data_g.old_data_uc)
         {
            /* TX Response ERROR */
            lin_slave_state_g = idle;
            lin_flag_g.tx_next = L_RESET;
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
            lin_hal_set_resp_error();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#ifdef J2602_PROTOCOL
            lin_hal_set_resp_error(J2602_DATA_ERROR);
#endif /* end #ifdef J2602_PROTOCOL */
         }
         else
         {
            /* if tx was okay, finish tx.  */
            lin_slave_state_g = idle;
            lin_slave_task_tx_data();
         }
#ifdef SUPPORT_TWO_BAUDRATES
         /* reset to higher baudrate if not yet set to a fixed value
            to be able to detect the lower one */
         l_hal_reset_to_high_baudrate();
#endif /* #ifdef SUPPORT_TWO_BAUDRATES */
         /* Reset transmission ongoing flag */
         lin_timeout_ctrl.flag.transm_ongoing = 0u;
         break;

      case tx_data:
			   break;
			
			default:
         /* Impossible Slave State... */
         lin_slave_state_g = idle;
         break;
   }
}

/* ---------------------------------------------------------------------------
 *  void lin_hal_ISR(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Interrupt service routine for receive interrupt. Can be also used for
           polling (then it should be called once each bit).
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
void lin_hal_ISR(void)
{
#ifdef AUTOBAUD_ENABLED
   l_u8 temp_linst;
#endif /* end #ifdef AUTOBAUD_ENABLED */

   g_lin_irqState = l_sys_irq_disable();
   /* get values from SCI */
   lin_hal_rx_data_guc = (l_u8) LIN_UART_BUFFER;
   lin_hal_status_g.stopbit = (l_u8) LIN_UART_9BITREC;
#ifdef AUTOBAUD_ENABLED
   temp_linst = (l_u8) LIN_UART_STATUS;
   LIN_UART_CLR_STATUS = LINST_MASK_SYNBRK;
#endif /* end #ifdef AUTOBAUD_ENABLED */
   l_sys_irq_restore(g_lin_irqState);

#ifdef LIN_PROTOCOL_VERSION_2_1
   g_lin_status_word.flag.bus_activity = L_SET;
#endif /* end #ifdef LIN_PROTOCOL_VERSION_2_1 */

#ifdef AUTOBAUD_ENABLED
   /* Detect Break characters, configure and start T2 to start on next falling edge (startbit of Synch-field) */
   if (((temp_linst & LINST_MASK_SYNBRK) == 0u) && (lin_hal_rx_data_guc == 0u) && (lin_hal_status_g.stopbit == 0u))
   {
      lin_ab_t2_state = 1u;
      lin_ab_timeout_timer = 0u;
      /* Start baudrate measurement */
      g_lin_irqState = l_sys_irq_disable();
      LIN_UART_SYNEN = 1u;
      LIN_UART_BR_SYN_DET =   BG_SEL;
      LIN_UART_BR_DIS = 1u;
      LIN_UART_BR_DIS = 0u;
      LIN_UART_CLR_STATUS = LINST_MASK_SYNBRK;
      lin_hal_init_T2();
      l_sys_irq_restore(g_lin_irqState);
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
      lin_hal_set_resp_error();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#ifdef J2602_PROTOCOL
      lin_hal_set_resp_error(J2602_FRAMING_ERROR);
#endif /* end #ifdef J2602_PROTOCOL */
      lin_slave_state_g = break_received;
   }
   /* Break and End of Synch Field detected */
   else if ((temp_linst & LINST_MASK_SYNBRK) == LINST_FLAG_EOFSYN)
   {
      /* IRQ not active */
   }
   /* Break detected w/o End of Synch Field */
   else if ((temp_linst & LINST_MASK_SYNBRK) == LINST_FLAG_ERRSYN)
   {
      /* IRQ not active */
   }
   /* End of Synch Field detected w/o Break */
   else if ((temp_linst & LINST_MASK_SYNBRK) == LINST_FLAG_BRK)
   {
      /* IRQ not active */
   }
   /* received a normal byte without framing error */
   else
#endif /* #ifdef AUTOBAUD_ENABLED */
   {
      /* Detected a framing error */
      if (lin_hal_status_g.stopbit == 0u)
      {
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
         lin_hal_set_resp_error();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#ifdef J2602_PROTOCOL
         lin_hal_set_resp_error(J2602_FRAMING_ERROR);
#endif /* end #ifdef J2602_PROTOCOL */
#ifndef AUTOBAUD_ENABLED
         /* Sync Break */
         if ( lin_hal_rx_data_guc == 0u)
         {
            lin_slave_state_g = break_received;
         }
#endif /* #ifndef AUTOBAUD_ENABLED */
      }
      else
      {
         /* byte received */
         if (lin_slave_state_g == tx_data)
         {
            if (lin_hal_rx_data_guc != lin_tx_data_g.old_data_uc)
            {
               /* TX Data error */
               lin_slave_state_g = idle;
               lin_flag_g.tx_next = L_RESET;
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
                     lin_hal_set_resp_error();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
#ifdef J2602_PROTOCOL
                     lin_hal_set_resp_error(J2602_DATA_ERROR);
#endif /* end #ifdef J2602_PROTOCOL */
            }
            else
            {
               /* if tx was okay, send next field */
               l_hal_tx_state_machine();
            }
         }
         else
         {
            if (lin_slave_state_g != idle)
            {
               l_hal_master_send_pid();
#if ((!defined LIN_MASTER) && (!defined J2602_MASTER))
               lin_hal_status_g.byte_received = L_SET;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */
            }
            else
            {
               /* no data field */
               lin_slave_state_g = idle;
               /* During header transmission baudrate is changed, break is transmitted
                * as normal 0x00 data byte but state is still idle. */
               l_hal_master_send_sync();
            }
         }
      }
   }
   return;
}

#ifdef AUTOBAUD_ENABLED
/* ---------------------------------------------------------------------------
 *  void lin_hal_T2_ISR(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Interrupt service routine for autobaud timer interrupt. Can be also used for
           polling (then it should be called once each bit).
   @pre    LIN driver initialized
   @param  void
   @retval void
*/
void lin_hal_T2_ISR(void)
{
   if (lin_ab_t2_state == 5u)
   {
      LIN_TIMER_RUN = 0u;
      LIN_TIMER_EXT_IR_EN = 0u;
      LIN_TIMER_EXT_EN = 0u;
      lin_ab_t2_state = 0u;
      lin_synch_time = (l_u16) ((l_u16)((l_u16)LIN_TIMER_CAP_H << 8u) | ((l_u16)LIN_TIMER_CAP_L));
      lin_hal_brreg_calc();
   }
   else
   {
      lin_ab_t2_state++;
   }
}
#endif /* end #ifdef AUTOBAUD_ENABLED */

/* ---------------------------------------------------------------------------
 *  void lin_hal_init_uart(void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Initializes the UART / SCI
   @param  void
   @retval void
*/
static void lin_hal_init_uart(void)
{
   /* Reset UART to initial values */
   LIN_UART_CONTROL =      0x00u;

   /* Set UART to 8bit shift UART */
   LIN_UART_MODE0 =        0u;
   LIN_UART_MODE1 =        1u;

   /* Set Baudrate Generator and enable */
   LIN_UART_BCON_PRE =     BRG_PRE;
   LIN_UART_BCON_FDSEL =   BRG_FD_SEL;
   LIN_UART_BCON_BG =      BRG_VAL;
   LIN_UART_BCON_RUN =     1u;

   /* Set Limits for Baudrate detection */
#ifdef AUTOBAUD_ENABLED
   LIN_UART_STATUS =       0x40u;
   LIN_UART_CLR_STATUS =   LINST_MASK_SYNBRK;
#else
   LIN_UART_STATUS =       0x01u;
   LIN_UART_CLR_STATUS =   LINST_MASK_SYNBRK;
#endif /* end #ifndef AUTOBAUD_ENABLED */

   LIN_UART_BR_SYN_DET =   BG_SEL;
#ifdef AUTOBAUD_ENABLED
   LIN_UART_BR_DIS = 1u;
   LIN_UART_BR_DIS = 0u;
   LIN_UART_CLR_STATUS =   LINST_MASK_SYNBRK;
#endif /* end #ifndef AUTOBAUD_ENABLED */

   /* Enable UART reception */
   LIN_UART_RUN =          1u;

   /* UART interrupt enable */
   LIN_UART_IR_SET_EN =    1u;
   LIN_UART_IR_EN =        1u;
   LIN_UART_IRTX_EN =      0u;
   LIN_UART_IR_PENDING =   1u;
   NVIC_SetPriority((IRQn_Type)LIN_UART_IRQ_NR ,LIN_INTERRUPT_PRIORITY);

#ifdef AUTOBAUD_ENABLED
   /* Select input EXINT0_2 for external interrupt 0. */
   LIN_TIMER_MODPISEL = 2u;
   /* Timer 2 external input is selected by MODPISEL2. */
   LIN_TIMER_MODPISEL1 = 0u;
   /* Timer2 external input is T2Ex_x (T2EXISCNF) */
   LIN_TIMER_MODPISEL2 = 0x0200u;

   LIN_TIMER_PRE =         0u;  /* T2CLK = PCLK (20MHz) */
   LIN_TIMER_PRE_EN =      1u;  /* Timer2 Prescaler is used (T2PRE) */
   LIN_TIMER_COUNTER_EN =  0u;  /* UpDown Counter function disabled */
   LIN_TIMER_EDGE_SELECT = 0u;  /* Timer2 starts on external falling edge */
   LIN_TIMER_EXT_START =   1u;  /* Timer2 starts on external event */

   LIN_TIMER_CAP_REL =     1u;  /* Capture Mode */
   LIN_TIMER_T_C_SEL =     0u;  /* Timer function */
   LIN_TIMER_EXT_EN =      0u;  /* External Events disabled */

   /* set Timer2 interrupts */
   LIN_TIMER_EXT_IR_EN =   0u;  /* Interrupt for external events disabled */
   LIN_TIMER_INT_IR_EN =   0u;  /* Interrupt for Timer2 overflow disabled */

   /* Timer2 is needed for baudrate synchronization */
   LIN_UART_IR_SET_EN =    1u;
#endif /* end #ifdef AUTOBAUD_ENABLED */
}

#ifdef AUTOBAUD_ENABLED
static void lin_hal_init_T2 (void)
{
   LIN_UART_BCON_RUN = 0u;          /* stop baudrate generator */
   LIN_TIMER_RUN = 0u;              /* stop timer for reinit */

   LIN_TIMER_HIGH = 0u;             /* reset the count value to '0' */
   LIN_TIMER_LOW = 0u;

   LIN_TIMER_EXT_EN = 1u;           /* External Events enabled */
   LIN_TIMER_EXT_IR_EN = 1u;        /* Interrupt for external events enabled */
   LIN_UART_CLR_STATUS = LINST_MASK_SYNBRK;
   lin_ab_timeout_timer = 0u;
}
#endif /* end ifdef AUTOBAUD_ENABLED */

#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1) || (defined J2602_PROTOCOL))
/* ---------------------------------------------------------------------------
 *  void lin_hal_set_resp_error ()
 * --------------------------------------------------------------------------*/
/**
   @brief  Set Response Error flag and Statusword Update correctly dependent
           of current driver state.
   @note   Response error is set latest at beginning of a new synch break - if
           not timed out before via ld_task(). Flags are set again earliest at
           PID recognition.
   @param  void
   @retval void
 */
#if (defined J2602_PROTOCOL)
static void lin_hal_set_resp_error (l_u8 j2602_fault)
#else
static void lin_hal_set_resp_error (void)
#endif /* end #if defined J2602_PROTOCOL */
{
   /* Protect setting of variables in different contexts */
   g_lin_irqState = l_sys_irq_disable();
#ifndef GM_SPEC_ADAPTION
   if ((lin_timeout_ctrl.flag.recept_started != 0u) || (lin_timeout_ctrl.flag.transm_ongoing != 0u))
#else
   /* GM specific J2602 adaption needs also the PID errors shown in the response error flag */
   if ((lin_timeout_ctrl.flag.recept_started != 0u)
         || (lin_timeout_ctrl.flag.transm_ongoing != 0u)
         || ((g_j2602_status.flags.errorstate & 0x10) != 0u))
#endif /* #ifndef GM_SPEC_ADAPTION */
   {
#ifdef LIN_EVENT_TRIGGERED_FRAME_ENABLE
      if(g_lin_rx_ctrl.flag.evttrgfrm == 0u)
#endif /* #ifdef LIN_EVENT_TRIGGERED_FRAME_ENABLE */
      {
#if ((defined(J2602_PROTOCOL)) && (!(defined(GM_SPEC_ADAPTION))))
         /* J2602 errors are assembled in a variable for assembling the statusword when required for
          * transmission of a designated frame containing the status byte.
          * If receiving a broadcast frame ignore errors. */
         if (lin_timeout_ctrl.flag.recept_started == 1u)
         {
            if ((g_lin_active_pid != 0x78u) && (g_lin_active_pid != 0xBAu)
               && (g_lin_active_pid != 0x39u) && (g_lin_active_pid != 0xFBu))
            {
               g_j2602_status.flags.errorstate |= j2602_fault;
            }
         }
         else
         {
            /* If - Else is necessary because after reception of the first byte during a subscribe frame
             * the transm_ongoing flag is also set to indicate that a first data byte of a frame has been
             * received.
             * If a frame was being transmitted, indicate that the status byte was not successfully transmitted. */
            if (lin_timeout_ctrl.flag.transm_ongoing == 1u)
            {
               g_j2602_status.flags.errorstate |= j2602_fault;
               g_j2602_status.flags.status_byte_transm = 0u;
            }
         }
#endif /* end #ifndef J2602_PROTOCOL */
#ifdef GM_SPEC_ADAPTION
         /* Set errors except for broadcast frames. */
         if ((g_lin_active_pid != 0x78u) && (g_lin_active_pid != 0xBAu)
            && (g_lin_active_pid != 0x39u) && (g_lin_active_pid != 0xFBu))
         {
            LIN_STATUS_BYTE(1u);
         }
#endif /* end #ifdef GM_SPEC_ADAPTION */
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
         l_Set_Response_Error_Flag();
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 */
      }
      if (g_lin_status_word.flag.last_pid != 0x0u)
      {
         g_lin_status_word.flag.overrun = L_SET;
      }
      g_lin_status_word.flag.last_pid = g_lin_active_pid;
      g_lin_status_word.flag.error_in_resp = L_SET;
   }
   lin_timeout_ctrl.flag.recept_started = 0u;
   lin_timeout_ctrl.flag.transm_ongoing = 0u;
#ifdef LIN_EVENT_TRIGGERED_FRAME_ENABLE
   /* Reset flag to indicate an event triggered frame (receive or transmit) */
   g_lin_rx_ctrl.flag.evttrgfrm = L_RESET;
#endif /* #ifdef LIN_EVENT_TRIGGERED_FRAME_ENABLE */
   l_sys_irq_restore(g_lin_irqState);
}
#endif /* end #if defined LIN_PROTOCOL_VERSION_2_0 || defined LIN_PROTOCOL_VERSION_2_1 || defined J2602_PROTOCOL */

#if ((defined LIN_MASTER)||(defined J2602_MASTER))
/* ---------------------------------------------------------------------------
 *  void l_hal_master_send_sync (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Starts sending the sync field (0x55).
   @param  void
   @retval void
 */
static void l_hal_master_send_sync(void)
{
   if ((lin_masterctrl.flag.break_transm == 1u) && (lin_hal_rx_data_guc == 0u))
   {
      /* Send Sync Field data to UART to transmit Sync Field */
      LIN_UART_BCON_RUN = 0u;
      LIN_UART_BCON_FDSEL = BRG_FD_SEL;
      LIN_UART_BCON_BG = BRG_VAL;
      LIN_UART_BCON_RUN = 1u;
      lin_hal_tx_char(SYNC_FIELD_k);
      lin_masterctrl.flag.syncf_transm = 1u;
      lin_masterctrl.flag.break_transm = 0u;
      lin_slave_state_g = break_received;
   }
}

/* ---------------------------------------------------------------------------
 *  void l_hal_master_send_pid (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Starts sending the PID.
   @param  void
   @retval void
 */
static void l_hal_master_send_pid(void)
{
   if (lin_masterctrl.flag.syncf_transm == 1u)
   {
      if (lin_hal_rx_data_guc == 0x55u)
      {
         lin_hal_tx_char(guc_frame_id);
         lin_slave_state_g = sync_received;
      }
      else
      {
         lin_slave_state_g = idle;
      }
      lin_masterctrl.flag.syncf_transm = 0u;
   }
   else
   {
      lin_hal_status_g.byte_received = L_SET;
   }
}
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */

/* ---------------------------------------------------------------------------
 *  void l_frame_timeout_control ()
 * --------------------------------------------------------------------------*/
/**
   @brief  Resets the UART when frame is not expected to continue.
   @param  void
   @retval void
 */
void l_frame_timeout_control(void)
{
   if(lin_timeout_ctrl.flag.frame != 0u)
   {
      lin_frm_timeout_timer++;
#ifdef LIN_PROTOCOL_VERSION_1_3
      /* Set LIN frame timeout correct for LIN 1.3 - depending on frame lengths - value is generated by LDC-Tool. */
      if(g_lin_frame_index < LIN_NUMBER_OF_FRAMES)
      {
         lin_frm_timeout_threshold = const_Lin_Frame_Timeout[g_lin_frame_index];
      }
      else
      {
         lin_frm_timeout_threshold = LIN_FRAME_TIMEOUT;
      }
      if (lin_frm_timeout_timer >= lin_frm_timeout_threshold)
#else
      /* LIN 2.x has no defined frame timeout, for reliability frame times out after receiving no byte for a certain time. */
      if(lin_frm_timeout_timer >= LIN_FRAME_TIMEOUT)
#endif /* end #ifdef LIN_PROTOCOL_VERSION_1_3 */
      {
         /* Timeout elapsed. Check before re-initialization if receiver is busy or framing error occured. The UART shall not be stopped and
         * re-initialized during reception of a new byte because it could be a sync-break. */
#ifdef LIN_PROTOCOL_VERSION_1_3
         if((lin_frm_timeout_timer >= (lin_frm_timeout_threshold + LIN_FRAME_TIMEOUT_DELAY)) ||
            ((lin_frm_timeout_timer >= LIN_FRAME_TIMEOUT) && (0u == (LINUART->SR_b.RBSY))))
#else
         if((lin_frm_timeout_timer >= (LIN_FRAME_TIMEOUT + LIN_FRAME_TIMEOUT_DELAY)) /*||
            ((lin_frm_timeout_timer >= LIN_FRAME_TIMEOUT) && (0u == (LINUART->SR_b.RBSY)))*/)
#endif /* end #ifdef LIN_PROTOCOL_VERSION_1_3 */
         {
            lin_slave_state_g = idle;
#if ((defined LIN_MASTER) && (defined LIN_EVENT_TRIGGERED_FRAME_ENABLE))
            if (lin_timeout_ctrl.flag.recept_started == 1u)
            {
               lin_master_check_etf();
            }
#endif /* end #if (((defined LIN_MASTER) || (defined J2602_MASTER)) && (defined LIN_EVENT_TRIGGERED_FRAME_ENABLE)) */
#if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1))
            lin_hal_set_resp_error();
#endif /* end #if ((defined LIN_PROTOCOL_VERSION_2_0) || (defined LIN_PROTOCOL_VERSION_2_1)) */
#if (defined LIN_PROTOCOL_VERSION_1_3)
            lin_frm_timeout_threshold = 0u;
#endif /* end #if defined LIN_PROTOCOL_VERSION_1_3 */
            lin_timeout_ctrl.flag.frame = 0u;
            lin_frm_timeout_timer = 0u;
            lin_slave_state_g = idle;
         }
         else
         {
            /* Receiver busy, wait until next byte received and evaluated. */
         }
      }
   }
}

#ifdef AUTOBAUD_ENABLED
/* ---------------------------------------------------------------------------
 *  void l_autobaud_control (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This checks regularly the state of the baudrate synchronization.
   @note   If the process takes too long the synchronization is being stopped and normal 
           the UART returns to normal communication with default values. 
   @param  void
   @retval void
 */
void l_autobaud_control(void)
{
   if(lin_ab_t2_state != 0u)
   {
      lin_ab_timeout_timer++;
      if(lin_ab_timeout_timer >= LIN_AUTOBAUD_TIMEOUT)
      {
         lin_slave_state_g = idle;
         lin_hal_init_uart();
         lin_ab_t2_state = 0u;
         lin_ab_timeout_timer = 0u;
      }
   }
}

/* ---------------------------------------------------------------------------
 *  void l_hal_baudrate_control (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function verifies regularly the measured baudrate against the set limits.
   @note   This grants additional stability in case that the baudrate measurement fails in 
           an unexpected way. 
   @param  void
   @retval void
 */
void l_hal_baudrate_control(void)
{
   l_u16 lin_temp_word;
   if (lin_slave_state_g == idle)
   {
      lin_temp_word = (l_u16) LIN_UART_BCON_BG;
      if (lin_temp_word > MAX_BDREG)
      {
         LIN_UART_BCON_FDSEL = BRG_FD_SEL;
         LIN_UART_BCON_BG = BRG_VAL;
      }
      if (lin_temp_word < MIN_BDREG)
      {
         LIN_UART_BCON_FDSEL = BRG_FD_SEL;
         LIN_UART_BCON_BG = BRG_VAL;
      }
   }
}

/* ---------------------------------------------------------------------------
 *  void lin_hal_brreg_calc (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function calculates the baudrate at the end of the measurement.
   @note   Autobaud synchronization, timer runs with no prescaler, formulae allows 
           to calculate necessary baudrate settings only with shifting.
           If not within valid limits, increase timeout timer to cause next call 
           of ld_task to reset UART.
   @param  void
   @retval void
 */
static void lin_hal_brreg_calc(void)
{
   lin_synch_time = (l_u16)(((l_u16)(lin_synch_time >> 2u)) >> BRG_PRE);
   /* (MISRA-C:2004 MISRA Rule 13.7/R, 14.1/R, e506) Constant value Boolean
    * Outcome depends on generated code. */
   LIN_UART_BCON_FDSEL = (l_u8) (((l_u8)(lin_synch_time & 0x1Fu)) >> ((BRG_PRE == 0u)?1u:0u)); /*lint !e506*/
   lin_synch_time = (l_u16) (lin_synch_time >> 5u);
   if (lin_synch_time >= MIN_BDREG)
   {
      if (lin_synch_time <= MAX_BDREG)
      {
         LIN_UART_BCON_BG = (uint32_t)((uint32_t)lin_synch_time & 0x7FFu);
         lin_slave_state_g = sync_received;
      }
      else
      {
         lin_ab_timeout_timer = LIN_AUTOBAUD_TIMEOUT + 1u;
         lin_ab_t2_state = 7u;
      }
   }
   else
   {
      lin_ab_timeout_timer = LIN_AUTOBAUD_TIMEOUT + 1u;
      lin_ab_t2_state = 7u;
   }
   LIN_UART_BCON_RUN = 1u;
}
#endif /* ifdef AUTOBAUD_ENABLED */

/* ---------------------------------------------------------------------------
 *  void lin_hal_wait_for_break (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  This function resets the state of the LIN driver to waiting for the next frame.
   @param  void
   @retval void
 */
void lin_hal_wait_for_break(void)
{
   lin_slave_state_g = idle;
#if ((defined LIN_MASTER)||(defined J2602_MASTER))
   lin_timeout_ctrl.flag.frame = 0u;
   lin_frm_timeout_timer = 0u;
#endif /* #if ((defined LIN_MASTER)||(defined J2602_MASTER)) */
}

/* ---------------------------------------------------------------------------
 *  void l_hal_cyclic_call (void)
 * --------------------------------------------------------------------------*/
/**
   @brief  Processes the received byte and decides on the next action.
   @note   This process generates usually the highest workload during PID recognition.
   @param  void
   @retval void
 */
void l_hal_cyclic_call(void)
{ 
   if(lin_hal_is_byte_received())
   { 
      lin_hal_reset_byte_received();
      l_hal_rx_state_machine();
   }
   if (l_txchk_byte_nr > 0u)
   { 
      l_hal_txchecksum_calculation();
   }
}
