/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2018-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** CE           Christian Engel                                               **
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2018-08-31, CE:   Inital version                                   **
** V1.1.0: 2020-03-02, JO:   Updated revision history format                  **
** V1.1.1: 2022-01-21, JO:   EP-934: Updated copyright and branding           **
** V1.1.2: 2023-08-21, BG:   EP-1195: Updated compiler version to ARMCC V6    **
**                           Updated type conversion                          **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Math: Integer divisions                                                    **
********************************************************************************
** This example performs integer divisions.                                   **
** It shows the performance of the MATH module compared to normal C code      **
** integer division.                                                          **
** Supported modes are data types are:                                        **
** 32/32 - 32/16 - 16/16 bit; all signed or unsigned                          **
**                                                                            **
** The SysTick Timer is used to measure the duration of the divisions.        **
** Even with Compiler optimization level -O3 (current setting)                **
** the MATH module is faster.                                                 **
**                                                                            **
** LEDs indicate the calculation speed:                                       **
**  - LED_P1_4: The Math module division was faster                           **
**  - LED_P0_3: Normal division in C was faster                               **
** LEDs indicate the correctnedd of the result:                               **
**  - LED_P0_1: The quotients of both divisions are the same                  **
**  - LED_P0_2: The remainders of both divisions are the same                 **
**                                                                            **
** Expected output: Math module is up to 4x faster than normal C division.    **
** While debugging you can see the SysTick ticks required in the variables    **
** sysTickDiffStd for normal division and sysTickDiffMath for Math module.    **
*******************************************************************************/

#include "tle_device.h"

static uint32 sysTickDiffStd, sysTickDiffMath;

int main(void)
{
  sint16 dividend;
  sint16 divisor;
  sint32 stdResultQuot, stdResultRmd, mathResultQuot, mathResultRmd;
  uint32 sysTickBegin, sysTickEnd;
  
  /*****************************************************************************
  ** Initialization of the hardware modules based on the configuration set    **
  ** in Config Wizard                                                         **
  *****************************************************************************/
  TLE_Init();

	/* Input values for division */
  dividend = 4242;
  divisor = 17;
	
	/* Perform MATH division */
  /* Current System Count at the beginning of calculation */
  sysTickBegin = CPU->SYSTICK_CVR.bit.CURRENT;
  
  /* Set dividend and divisor for operation             */
  /* Calculation starts with the setting of the divisor */
  MATH->DVD.reg = (uint32)dividend;
  MATH->DVS.reg = (uint32)divisor;
  
  /* Wait for the calculation to finish, needs 35 System Ticks */
  /* You can execute any code in parallel to the calculation with the Math module */
  while(MATH_BSY_Sts())
  {
  }
  mathResultQuot = (sint32)MATH->QUOT.bit.VAL;
  mathResultRmd = (sint32)MATH->RMD.bit.VAL;
  
  /* Calculate the System Ticks needed for whole operation */
  sysTickEnd = CPU->SYSTICK_CVR.bit.CURRENT;
  sysTickDiffMath = sysTickBegin - sysTickEnd;

	
	/* Perform normal C code division */
  /* Current System Count at begin of calculation */
  sysTickBegin = CPU->SYSTICK_CVR.bit.CURRENT;

  {
    stdResultQuot = dividend / divisor;
    stdResultRmd = dividend % divisor;
  }


  /* Calculate the System Ticks needed for whole operation */
  sysTickEnd = CPU->SYSTICK_CVR.bit.CURRENT;
  sysTickDiffStd = sysTickBegin - sysTickEnd;


  /* Compare both calculations */
  /* Set LEDs if both calculations deliver the same results */
  if(stdResultQuot == mathResultQuot) 
  {
    PORT_P01_Output_High_Set();
  }
  if(stdResultRmd == mathResultRmd)
  {
    PORT_P02_Output_High_Set();
  }

  /* Set LED_P1_4 if Math module was faster, else set LED_P0_3 */
  if(sysTickDiffStd > sysTickDiffMath) 
  {
    PORT_P14_Output_High_Set();
  }
  else
  {
    PORT_P03_Output_High_Set();
  }
    
  for (;;)
  {
    (void)WDT1_Service();
  }
}


