/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2020-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-03-02, JO:   Initial version of revision history              **
** V1.0.1: 2022-01-21, JO:   EP-934: Updated copyright and branding           **
** V1.0.2: 2023-08-21, BG:   EP-1195: Updated compiler version to ARMCC V6    **
**                           Added missing function declarations              **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Flash: Program one page in data flash                                      **
********************************************************************************
** Reading the first data flash page after page erase leads to an NMI.        **
** Inside the NMI ISR, the first data flash page will be filled with data     **
** consecutive read inside the main application.                              **
** Now it is possible to read from them from the data flash.                  **
** LED_P1_4 on: flash erase/write/read was correct (expected behavior)        **
** LED_P1_2 on: error occured during flash operation                          **
*******************************************************************************/

#include "tle_device.h"

void NVM_Handle_PageFault(void);

/* Allocate one flash page in RAM - 1024 Bytes */
static uint8 TargetData[FlashPageSize];
static int32_t NVM_Result;

int main(void)
{
  uint8 i = 0;
  uint8 *p = NULL_PTR;
  static uint16 checksum = 0, data = 0; 	
	
  /*****************************************************************************
  ** Initialization of the hardware modules based on the configuration set    **
  ** in Config Wizard                                                         **
  *****************************************************************************/
  TLE_Init();
   
  /* Fill up TargetData array with increasing numbers */
  for(i = 0; i < FlashPageSize; i++)
  {
    TargetData[i] = i;
    checksum += i;
  }  
  
  /* Erase Data Flash sector */
  NVM_Result = user_nvm_sector_erase(DataFlashStart);
  
  /* Check if sector erase was successful */
  if(NVM_Result == ERR_LOG_SUCCESS)
  {
    /* Perform a read access to the first Data Flash page */
    /* Given the logical page 0 is not mapped to any physical flash page, a NMI will be issued */
    p = (uint8*) DataFlashStart;
    /* Read DataFlashStart + Offset (0) */
    data = (uint16) p[0];
    /* NMI ISR gets called, page 0 gets loaded with data */

    /* Check if preloading of data inside the NMI ISR did work */
    if(NVM_Result == ERR_LOG_SUCCESS)
    {
      /* Read DataFlashStart + Offset (0): you should be able to read data this time */
      data = 0;
      for(i = 0; i < FlashPageSize; i++)
      {
        data += (uint16) p[i];
      }
      
      if(data == checksum)
      {
        /* Data in Data Flash page 0 correct */
        PORT_P14_Output_High_Set();
      }
      
      else
      {
        /* Data in Data Flash page 0 wrong */
        PORT_P12_Output_High_Set();
      }
    }
    
    else
    {
      /* An error happened during Page Write in the NMI ISR */
      PORT_P12_Output_High_Set();
    }
  }
  
  else
  {
    /* An error happened during Erase Sector */
    PORT_P12_Output_High_Set();
  }
  
  for (;;)
  {
    (void)WDT1_Service();
  }
}

void NVM_Handle_PageFault(void)
{
  /* Fill up first page with some data */
  /* The TargetData array will be written to page 0 */
  
  /* Disable interrupts */
  __disable_irq();
  
  /* Service WDT1 short open window */
  WDT1_SOW_Service(1);
  
  /* Program NVM page */
  NVM_Result = user_nvm_write(DataFlashStart, TargetData, FlashPageSize, 0);
  
  /* Close short open window */
  WDT1_Service();
  
  /* Enable interrupts */
  __enable_irq();
}
