/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2020-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-03-02, JO:   Initial version of revision history              **
** V1.0.1: 2022-01-21, JO:   EP-934: Updated copyright and branding           **
** V1.0.2: 2023-08-21, BG:   EP-1195: Updated compiler version to ARMCC V6    **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** Flash: Program a page when the write protection is set                     **
********************************************************************************
** Read the customer id to determine the design step.                         **
** Depending on the design step, the correct method is applied to set the     **
** protection.                                                                **
** A page write is performed in the protected NVM region. This operation      **
** should failed due to the protection.                                       **
**                                                                            **
** The password (here 0x40000000) is encoded the following way:               **
**  - bit[31] = 0 => enable read protection (here '0')                        **
**  - bit[30] = 1 => enable write protection (here '1')                       **
**  - bit[29:0] = user password (here all '0')                                **
** The password has to be set either through a BSL command or with the        **
** user API "user_nvm_password_set".                                          **
** If no password was set before, then the password along with the function   **
** "user_nvm_protect_set" is ignored.                                         **
** The Bits[31:30] are processed in any case. The protection will then be     **
** set temporarily only.                                                      **
**                                                                            **
** The LEDs will tell you the status of your operation:                       **
** No active LEDs: Setting write protection successful, clearing of the       **
**                 protection failed in 2nd step                              **
** Only LED_P1_2 active: Flash write protection was not set                   **
** LED_P1_2 and LED_P1_4 active: Setting and clearing of write protection     **
**                               was successful                               **
*******************************************************************************/

#include "tle_device.h"

/* Allocate one flash page in RAM */
static uint8 TargetData[FlashPageSize];
static int32_t NVM_Result;

int main(void)
{
  /*****************************************************************************
  ** Initialization of the hardware modules based on the configuration set    **
  ** in Config Wizard                                                         **
  *****************************************************************************/
  TLE_Init();
   
  WDT1_SOW_Service(1);
  
  NVM_Result = user_nvm_protect_set(0x40000000, NVM_PASSWORD_SEGMENT_DATA);
  
  (void)WDT1_Service();
  
  /* Fill up the TargetData array with increasing numbers */
  for(uint8 i = 0; i < FlashPageSize; i++)
  {
    TargetData[i] = i;
  }
    
  /* Call ProgramPage routine */
  /* If the write protection is enabled, the ProgramPage routine returns an error */
  
  /* Disable interrupts */
  __disable_irq();
  
  /* Service WDT1 short open window */
  WDT1_SOW_Service(1);
  
  /* Program NVM page */
  NVM_Result = user_nvm_write(DataFlashStart, TargetData, FlashPageSize, 0);
  
  /* Close short open window */
  WDT1_Service();
  
  /* Enable interrupts */
  __enable_irq();
  
  if(NVM_Result == ERR_LOG_SUCCESS)
  {
    /* Data in page 0 of the Data Flash is correct */
    PORT_P12_Output_High_Set();
  }
  else if(NVM_Result == ERR_LOG_CODE_USER_PROTECT_NVM_WRITE_PROTECTED)
  {
     /* NVM is write protected */
     PORT_P14_Output_High_Set();
  }
  else 
  {
    /* An error has occurred */
    PORT_P12_Output_High_Set();
  }
  
  /* Clearing the write protection to be able to use the controller afterwards */
  NVM_Result = user_nvm_protect_clear(0x40000000, NVM_PASSWORD_SEGMENT_DATA);
  
  if(NVM_Result == ERR_LOG_SUCCESS)
  {
    PORT_P12_Output_High_Set();
  }
  else if(NVM_Result == ERR_LOG_CODE_USER_PROTECT_NVM_WRITE_PROTECTED)
  {
    PORT_P14_Output_Toggle_Set();
  }
  else
  {
    PORT_P12_Output_High_Set();
  }
  
  for (;;)
  {
    (void)WDT1_Service();
  }
}

