/*
 ***********************************************************************************************************************
 *
 * Copyright (c) 2020-2023, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/

/*******************************************************************************
**                             Author(s) Identity                             **
********************************************************************************
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** JO           Julia Ott                                                     **
** BG           Blandine Guillot                                              **
*******************************************************************************/

/*******************************************************************************
**                          Revision Control History                          **
********************************************************************************
** V1.0.0: 2020-03-02, JO:   Initial version of revision history              **
** V1.0.1: 2022-01-21, JO:   EP-934: Updated copyright and branding           **
** V1.0.2: 2023-08-21, BG:   EP-1195: Updated compiler version to ARMCC V6    **
**                           Updated variable type in Evaluate_Reset_Source() **
*******************************************************************************/

/*******************************************************************************
**                                  Abstract                                  **
********************************************************************************
** PMU: Power saving - Evaluation of the reset source                         **
********************************************************************************
** Send the device into:                                                      **
**  - Sleep mode by pulling P1.1 to high                                      **
**  - Stop mode by pulling P1.0 to high                                       **
** --> The device wakes up by MON (configured by default).                    **
** System fail is raised after 5 times not servicing the WDT1.                **
** This can be done by pulling P2.3 to high for the time of ~5*WDT1 period    **
**                                                                            **
** Check the LEDs on the evaluation board to know which reset was performed:  **
**  - LED_P1_2 = Power On Reset                                               **
**  - LED_P0_5 = PIN Reset                                                    **
**  - LED_P0_4 = Sleep Mode Exit                                              **
**  - LED_P0_3 = Stop Mode Exit (exit with Reset only)                        **
**  - LED_P1_4 = System Fail                                                  **
*******************************************************************************/

#include "tle_device.h"

void Evaluate_Reset_Source(void);

int main(void)
{
  /*****************************************************************************
  ** Initialization of the hardware modules based on the configuration set    **
  ** in Config Wizard                                                         **
  *****************************************************************************/
  TLE_Init();
  
  Evaluate_Reset_Source();

  for (;;)
  {
    (void)WDT1_Service();

    if (PORT_ReadPin(0x11) == 1)
    {
      SCU_EnterSleepMode();
    }
    if (PORT_ReadPin(0x10) == 1)
    {
      SCU_EnterStopMode();
    }
		if(PORT_ReadPin(0x23) == 1)
		{
			/* Wait until WDT1 fail */
			while(1){}
		}

  }
}

/* Evaluate the reset source and turns on a LED accordingly */
void Evaluate_Reset_Source(void)
{
  uint16 sts;
  sts = PMU_Get_Reset_Status();

  /* P1.2 turned on in case of a Power On Reset */
  if (sts & PMU_RESET_STS_POR)
  {
    PORT_P12_Output_High_Set();
  }
  
  /* P0.5 turned on in case of a Pin Reset */
  if (sts & PMU_RESET_STS_PIN)
  {
    PORT_P05_Output_High_Set();
  }

  /* P0.4 turned on in case of a sleep mode exit */
  if (sts & PMU_RESET_STS_SLEEP)
  {
    PORT_P04_Output_High_Set();
  }

  /* P0.3 turned on in case of a stop mode exit */
  if (sts & PMU_RESET_STS_WAKE)
  {
    PORT_P03_Output_High_Set();
  }

  /* P1.4 turned on in case of a system fail */
  if (sts & PMU_RESET_STS_SYS_FAIL)
  {
    PORT_P14_Output_High_Set();
  }

  PMU_Clear_Reset_Status();
}
